@@ -32,12 +32,15 @@
 
 #include <GL/gl.h>
 
-#include <gdk/GL/wglext.h>
-#include <gdk/GL/wglext-extra.h>
-
+#include <gdk/gdkgldefs.h>
 #include <gdk/gdkglquery.h>
 #include <gdk/gdkglconfig.h>
 
+#undef __wglext_h_
+#undef WGL_WGLEXT_VERSION
+#include <gdk/glext/wglext.h>
+#include <gdk/glext/wglext-extra.h>
+
 G_BEGIN_DECLS
 
 /*
